@@ -40,7 +40,7 @@ QString AccountModel::displayName() const
 
 void AccountModel::fillTimeline(const QString &fromId)
 {
-    if (m_accountId.isEmpty() || m_accountId.isNull()) {
+    if (m_accountId.isEmpty() || m_accountId.isNull() || loading()) {
         return;
     }
     setLoading(true);
@@ -173,6 +173,7 @@ void AccountModel::setAccountId(const QString &accountId)
     }
     Q_EMIT accountIdChanged();
 
+    reset();
     fillTimeline();
 }
 
