@@ -5,6 +5,9 @@
 #include "timeline/post.h"
 
 #include "account/abstractaccount.h"
+#include "accountmanager.h"
+#include "networkcontroller.h"
+#include "tokodon_debug.h"
 #include "utils/texthandler.h"
 
 #include <KLocalizedString>
@@ -31,6 +34,7 @@ Post::Post(AbstractAccount *account, QObject *parent)
     , m_parent(account)
     , m_attachmentList(this, &m_attachments)
 {
+    Q_ASSERT(account);
     QString visibilityString = account->identity()->visibility();
     m_visibility = stringToVisibility(visibilityString);
 }
@@ -41,6 +45,7 @@ Post::Post(AbstractAccount *account, QJsonObject obj, QObject *parent)
     , m_attachmentList(this, &m_attachments)
     , m_visibility(Post::Visibility::Public)
 {
+    Q_ASSERT(account);
     fromJson(obj);
 }
 
@@ -73,6 +78,33 @@ void Post::fromJson(QJsonObject obj)
 
     processContent(obj);
 
+    // Process all URLs in the body
+    const auto urlMatches = TextRegex::url.match(m_content);
+    if (urlMatches.hasMatch()) {
+        for (auto &url : urlMatches.capturedTexts()) {
+            // To whittle down the number of requests (which in most cases should be zero) check if the URL could point to a valid post.
+            if (TextHandler::isPostUrl(url)) {
+                // Then request said URL from our server
+                m_parent->requestRemoteObject(QUrl(url), this, [this](QNetworkReply *reply) {
+                    const auto searchResult = QJsonDocument::fromJson(reply->readAll()).object();
+
+                    const auto statuses = searchResult[QStringLiteral("statuses")].toArray();
+
+                    if (statuses.isEmpty()) {
+                        qCDebug(TOKODON_LOG) << "Failed to find any statuses!";
+                    } else {
+                        const auto status = statuses.first().toObject();
+
+                        m_quotedPost = new Post(m_parent, status, this);
+                        Q_EMIT quotedPostChanged();
+                    }
+                });
+
+                break;
+            }
+        }
+    }
+
     m_replyTargetId = obj["in_reply_to_id"_L1].toString();
 
     if (obj.contains("in_reply_to_account_id"_L1) && obj["in_reply_to_account_id"_L1].isString()) {
@@ -444,6 +476,11 @@ void Post::setCard(std::optional<Card> card)
     m_card = card;
 }
 
+Post *Post::quotedPost() const
+{
+    return m_quotedPost;
+}
+
 void Post::setApplication(std::optional<Application> application)
 {
     m_application = application;
